# Sup property

A superior to the builtin python `property` to support default values and validators
and even version and deprecation support.

This is a subclass of `property` so use the same way anywhere in your code.